@@ -7,10 +7,12 @@ def run(ibeg, iend):
 		j = str(10000 + i)
 		name = f"c4-train.0{j[1:]}-of-01024.docjsonlg.3.4.1.gz"
 		print (f"{name} is started, head={head}, j = {j}", flush=True) 
-		os.system(f"wget http://cpu76.wrask.com:8008/{head}/{name}")
+		os.system(f"wget http://daka.wrask.com:8008/{head}/{name}")
 		os.system(f"python3 c4np.py {name}")
 		os.remove(name)
+		os.system("sshpass -p cikuutest!2345 scp *.np.gz ubuntu@rabbitmq.wrask.com:/ftp/c4np")
+		os.system("rm *.np.gz")
 		print (f"{name} is done") 
 
 if __name__ == '__main__': 
-	fire.Fire(run) 
+	fire.Fire(run) 
\ No newline at end of file
