@@ -1,4 +1,4 @@
-# 2022.9.6
+# 2022.10.3
 import json, traceback,sys, time,  fileinput, os, en
 from collections import Counter
 
@@ -12,12 +12,14 @@ def run(infile):
 		for sid, line in enumerate(fileinput.input(infile,openhook=fileinput.hook_compressed)): 
 			try:
 				arr = json.loads(line.strip()) 
-				doc = spacy.from_json(arr) # ('PROPN','NUM','X','SPACE')
-				[ si.update({f"{t.dep_} {t.head.pos_} {t.head.lemma_} {t.pos_} {t.lemma_}" : 1 })  for t in doc if t.pos_ not in ('SP','PUNCT','PROPN')]
+				doc = spacy.from_json(arr) 
+				for t in doc:
+					if t.pos_ not in ('SP','PUNCT','PROPN') and t.tag_ not in ('NUM','CD') and not ':' in t.text :
+						trp = f"{t.dep_}:{t.head.pos_}:{t.pos_}:{t.head.lemma_}:{t.lemma_}:{t.head.tag_}:{t.tag_}" 
+						fw.write(f"{trp}\n")
 			except Exception as e:
 				print ("ex:", e, sid, line) 
-		for s, i in si.items(): 
-			fw.write(f"{s}\t{i}\n")
+	os.system(f"gzip -f -9 {outfile}")
 	print(f"{infile} is finished, \t| using: ", time.time() - start) 
 
 if __name__	== '__main__':
