@@ -9,10 +9,11 @@ def _oneself( t ) :
 	from dic.oneself import oneself 
 	return oneself.get(t.text.lower(), '') 
 
-def kps(sid, snt, doc, with_tok:bool=False): 
-	''' 2022.8.19 '''
-	postag = "_^ " + ' '.join([ f"_{t.pos_}_{t.tag_}" if t.pos_ in ('PROPN','NUM','X','SPACE') else f"{t.text if t.text in ('I') else t.text.lower()}_{t.lemma_}_{t.pos_}_{t.tag_}{_oneself(t)}"  for t in doc]) # uniq by ana #,'PUNCT'
+doc_toks = lambda sid, doc:  [ {'_id': f"{sid}-tok-{t.i}", '_source': {"type":"tok", "src":sid, 'i':t.i, "head":t.head.i, 'lex':t.text, 'lem':t.lemma_, 'pos':t.pos_, 'tag':t.tag_, 'dep':t.dep_, "gpos":t.head.pos_, "glem":t.head.lemma_ } } for t in doc ] 
+postag	=  lambda doc:  "_^ " + ' '.join([ f"_{t.pos_}_{t.tag_}" if t.pos_ in ('PROPN','NUM','X','SPACE') else f"{t.text if t.text in ('I') else t.text.lower()}_{t.lemma_}_{t.pos_}_{t.tag_}{_oneself(t)}"  for t in doc]) # uniq by ana #,'PUNCT'
 
+def sntdoc_kps(doc): 
+	''' doc is of single sent, 2022.9.6 '''
 	_kps = []
 	[ _kps.append(f"{t.pos_}:{t.lemma_}") for t in doc]  # VERB:book
 	[ _kps.append(f"_{t.lemma_}:{t.text.lower()}") for t in doc]  # _book:booked,  added 2022.8.21
@@ -43,8 +44,13 @@ def kps(sid, snt, doc, with_tok:bool=False):
 		if name in ('v_n_vbn','v_n_adj'): 
 			_kps.append(f"{name}:{doc[ibeg].pos_}_{doc[ibeg].lemma_}:{doc[ibeg].lemma_} {doc[ibeg+1].lemma_} {doc[ibeg+2].text}")
 
+	return list(set(_kps))
+
+def kps(sid, snt, doc, with_tok:bool=False): 
+	''' 2022.8.19 '''
+	postag = "_^ " + ' '.join([ f"_{t.pos_}_{t.tag_}" if t.pos_ in ('PROPN','NUM','X','SPACE') else f"{t.text if t.text in ('I') else t.text.lower()}_{t.lemma_}_{t.pos_}_{t.tag_}{_oneself(t)}"  for t in doc]) # uniq by ana #,'PUNCT'
 	actions = []
-	actions.append( {'_id': sid, '_source': {'type':'snt', 'snt':snt, 'postag':postag,  'src': sid,  'tc': len(doc), 'kps': list(set(_kps)) 	} } )
+	actions.append( {'_id': sid, '_source': {'type':'snt', 'snt':snt, 'postag':postag,  'src': sid,  'tc': len(doc), 'kps': sntdoc_kps(doc) } } )
 	if with_tok: [ actions.append( {'_id': f"{sid}-tok-{t.i}", '_source': {"type":"tok", "src":sid, 'i':t.i, "head":t.head.i, 'lex':t.text, 'lem':t.lemma_, 'pos':t.pos_, 'tag':t.tag_, 'dep':t.dep_, "gpos":t.head.pos_, "glem":t.head.lemma_ } }) for t in doc ] 
 	return actions
 
@@ -72,6 +78,7 @@ def kps_esjson(infile, outfile=None,  with_tok:bool=False,  withsi:bool=True):
 					fw.write(json.dumps(ar) + "\n") 
 			except Exception as e:
 				print ("ex:", e, sid, line) 
+		fw.write(json.dumps({'_id': "sntsum", '_source': {'s':"sntsum", 'i':sid+1 } }) + "\n")  # added 2022.9.4
 		if withsi and len(si) > 0: 
 			for s,i in si.items(): 
 				fw.write(json.dumps({'_id': s, '_source': {'s':s, 'i':i	} }) + "\n") 
