@@ -184,11 +184,10 @@ config = {
 			"kp": { "type": "keyword"},
 			"trp": { "type": "keyword"}, # open:VERB:dobj:NOUN:door
 			"cate": { "type": "keyword"},
-			"feedback": { "type": "keyword"},
 			"tail":{ "type": "keyword"},
 			"govpos":{ "type": "keyword"},
 			"deppos":{ "type": "keyword"},
-			"fd": { "type": "keyword"},
+			#"fd": { "type": "keyword"},
 			"si": {
 				   "type": "nested",
 				   "properties": {
@@ -196,6 +195,30 @@ config = {
 					  "i": {"type": "integer"}
 				   }
 				},
+			"fd": {
+				   "type": "nested",
+				   "properties": {
+					  "cate": {"type": "keyword"},
+					  "msg": {"type": "keyword"},
+					  "ibeg": {"type": "integer"}
+				   }
+				},
+			#{'i':t.i, "head":t.head.i, 'lex':t.text, 'lem':t.lemma_, 'pos':t.pos_, 'tag':t.tag_, 'dep':t.dep_, "gpos":t.head.pos_, "glem":t.head.lemma_ }
+			"tok": {
+				   "type": "nested",
+				   "properties": {
+					  "i": {"type": "integer"},
+					  "head": {"type": "integer"},
+					  "lex": {"type": "keyword"},
+					  "lem": {"type": "keyword"},
+					  "pos": {"type": "keyword"},
+					  "tag": {"type": "keyword"},
+					  "dep": {"type": "keyword"},
+					  "gpos": {"type": "keyword"},
+					  "glem": {"type": "keyword"}
+				   }
+				},
+
 			 "sntvec": {
 			   "type": "dense_vector",
 			   "dims": 384,
@@ -216,7 +239,7 @@ config = {
 				 },
 
 			"err": {"type": "text",  "analyzer": "err_ana"},
-			"fd": { "type": "keyword", "index": "false"},
+			#"fd": { "type": "keyword", "index": "false"},
 			"short_msg": { "type": "keyword", "index": "false"},
 			"arr": { "type": "keyword", "index": "false" }, # dim arr of dsk
 			"info": { "type": "keyword", "index": "false" ,"ignore_above": 50},
@@ -249,7 +272,7 @@ config = {
 			"v": { "type": "keyword",  "index": "false"},
 			"n": { "type": "keyword",  "index": "false"},
 			"adj": { "type": "keyword",  "index": "false"},
-			"snt": { "type": "text", "analyzer": "standard","store":"true"}
+			"snt": { "type": "text", "analyzer": "standard","fielddata":"true"} #,"store":"true"
 		  }
 		}
 	}
