@@ -2,10 +2,10 @@
 import json,fire,sys, os, time ,  fileinput, so
 from elasticsearch import Elasticsearch,helpers
 
-def run(infile, index:str=None, batch=10000, refresh:bool=False, eshost='127.0.0.1',esport=9200): 
+def run(infile, index:str=None, batch=200000, refresh:bool=False, eshost='127.0.0.1',esport=9200): 
 	''' python3 -m so.load gzjc.esjson.gz '''
 	es	  = Elasticsearch([ f"http://{eshost}:{esport}" ])  
-	if not index : index = infile.split('.')[0]
+	if index is None : index = infile.split('.')[0]
 	print(">>load started: " , infile, index, flush=True )
 	if refresh or not es.indices.exists(index=index): 
 		if es.indices.exists(index=index):es.indices.delete(index=index)
@@ -28,4 +28,9 @@ def run(infile, index:str=None, batch=10000, refresh:bool=False, eshost='127.0.0
 	print(">>load finished:" , infile, index )
 
 if __name__ == '__main__':
-	fire.Fire(run)
\ No newline at end of file
+	fire.Fire(run)
+
+'''
+GET /index_*/_search
+GET /index_01,index_02/_search
+'''
\ No newline at end of file
