@@ -40,6 +40,60 @@ def dsk_xgec(essay_or_snts:str="She has ready. It are ok.", asdsk:bool=True, tim
 	dsk['tim'] = {'gec': tims[1] - tims[0] , 'parse': tims[2] - tims[1] , 'mkf': tims[3] - tims[2] }
 	return dsk
 
+@app.post('/xgecmkf', tags=["dsk"])
+def xgecmkf(formula:dict={ 
+				"ast":[9.9, 11.99, 15.3, 18.51, 25.32,				2,0.0882, 0.3241],
+				"awl":[3.5, 4.1, 4.56, 5.1, 6.0,					3,0.0882, 0.5],
+				"b3":[0, 0.03, 0.08, 0.12, 0.15 ,					1, 0.0956, 0.2096],
+				"cl_sum":[1, 6.68, 12, 16, 26,						2,0.0441, 0.1621],
+				"grammar_correct_ri":[0.6, 0.85, 0.92, 0.97,1.0,	2,0.0368, 0.1352],
+				"internal_sim":[0.0, 0.08, 0.2, 0.3, 0.4,			4, 0.0735, 0.7688],
+				"kp_correct_ri":[0.7, 0.9, 0.95, 0.97, 1,			1, 0.0368, 0.0807],
+				"mwe_pv":[0.01,8.03, 12, 20.21, 25,					4, 0.0221, 0.2312],
+				"pred_diff_max3":[3.84, 5.11, 6.51, 7.9, 10.09 ,	1, 0.0368, 0.0807],
+				"prmods_ratio":[0.06, 0.21, 0.3, 0.4, 0.5,			2, 0.0294, 0.108],
+				"prmods_tc":[1.1, 2.76, 4.75, 6.76, 10.0,			2, 0.0368, 0.1352],
+				"simple_sent_ri":[0.4, 0.65, 0.9, 0.95, 1,			2, 0.0368, 0.1352],
+				"snt_correct_ratio":[0.01, 0.2, 0.45, 0.75, 1,		1, 0.0368, 0.0807],
+				"spell_correct_ratio":[0.8, 0.9, 0.97, 0.99, 1,		1, 0.1471, 0.3226],
+				"ttr1":[3.43, 4.28, 5.2, 6, 6.8,					3, 0.0882, 0.5],
+				"word_diff_avg":[4.47, 4.73, 5.25,5.8, 6.6,			1, 0.0441, 0.0967],
+				"word_gt7":[0.11, 0.19, 0.3, 0.42, 0.49,			1, 0.0588, 0.1289]}, 
+				essay_or_snts:str="She has ready. It are ok.", timeout:int=5, ttl:int=87200, gechost:str="192.168.201.120:6379",dskhost:str="172.17.0.1:7095"): # rgec_host:str='192.168.201.120', rgec_port:int=6379 , dskhost:str='172.17.0.1:7095'
+	''' 智慧课堂， 大量重复作文提交，1. with cache 2, gechost in the whiteIP list, 2022.10.30 '''
+	import redis
+	from dsk import score, sntsdims 
+	if not hasattr(xgecmkf,'r'): xgecmkf.r = redis.Redis(host=gechost.split(":")[0], port=int(gechost.split(":")[-1]), decode_responses=True)
+	snts	= json.loads(essay_or_snts) if essay_or_snts.startswith('["') else sntbr(essay_or_snts)
+	mkfs	= xgecmkf.r.mget([f"mkf:{snt}" for snt in snts])
+	newsnts = [snt for snt, mkf in zip(snts, mkfs) if mkf is None]
+
+	def	gec(snts): 
+		if not snts: return {}
+		id		= xgecmkf.r.xadd("xsnts", {'snts':json.dumps(newsnts)})
+		res		= xgecmkf.r.blpop([f"suc:{id}",f"err:{id}"], timeout=timeout)
+		xgecmkf.r.xdel("xsnts", id)
+		return	{} if res is None else json.loads(res[1])
+	sntdic	= gec(newsnts) 
+
+	def parse(snt): 
+		docjson = xgecmkf.r.get(f"spacy:{snt}") # spacy version: lg 3.4.1
+		doc		= spacy.nlp(snt) if docjson is None else spacy.tokens.Doc(spacy.nlp.vocab).from_json(json.loads(docjson)) 
+		if docjson is None: xgecmkf.r.setex(f"spacy:{snt}", ttl, json.dumps(doc.to_json()) )
+		return doc
+	docs	= [parse(snt) for snt in newsnts ] 
+
+	if newsnts: 
+		input	= mkf_input(newsnts, docs, spacy.nlp.tokenizer, sntdic)
+		mkfres	= requests.post(f"http://{dskhost}/parser", data={"q":json.dumps(input).encode("utf-8")}).json()
+		[ xgecmkf.r.setex("mkf:" + mkf.get('meta',{}).get('snt',''), ttl, json.dumps(mkf) ) for mkf in mkfres ]
+
+	dims	= sntsdims.docs_to_dims(snts, [parse(snt) for snt in snts ]) 
+	dscore	= score.dims_score(dims, formula) #{'formula_score': 70.01084449583234, 'cate_score': Counter({4: 78.72539112219452, 3: 76.10127717391306, 1: 70.11571816803196, 2: 62.80265151882237})}
+	return {"snts":snts, "spacys":xgecmkf.r.mget([f"spacy:{snt}" for snt in snts]), "mkfs": xgecmkf.r.mget([f"mkf:{snt}" for snt in snts]),
+		"dims": dims, "score": dscore }
+	#return [ {"snt": snt, "spacy":spacy, "mkf":mkf} for snt,spacy, mkf in zip( snts,  xgecmkf.r.mget([f"spacy:{snt}" for snt in snts]),  xgecmkf.r.mget([f"mkf:{snt}" for snt in snts]) ) ]
+
 @app.get('/dsk/register_redis', tags=["dsk"])
 def register_redis(rinfo:str='172.17.0.1:6379:0'):
 	''' to enable redis cache for snt parsing , 2022.6.30 '''
@@ -72,7 +126,7 @@ def post_dsk(arr:dict={'essay_or_snts':"She has ready. It are ok.", # arr from m
 	from gec_fastapi import gecsnts
 	try:
 		tims	= [ ("start", time.time(), 0)] # tag, tm, delta 
-		essay_or_snts = arr.get("essay_or_snts","")
+		essay_or_snts = arr.get("essay_or_snts", arr.get("essay","") )
 		snts	= json.loads(essay_or_snts) if essay_or_snts.startswith('["') else en.sntbr(essay_or_snts)
 		if hasattr(en,'redis_xsntbytes'): en.publish_newsnts(snts) 
 
@@ -213,7 +267,7 @@ def dsk_xessay(arr:dict={"essay_or_snts":"She has ready. It are ok."}, dskhost:s
 	return {"hdoc": arr, "hsnts": sntdic} 
 
 if __name__ == '__main__':  #uvicorn.run(app, host='0.0.0.0', port=80)
-	print ( dsk_xessay(), flush=True) 
+	print ( xgecmkf()) 
 	#print (dsk_wrapper("[\u8bd1\u6587]The 55-kilometre Hong Kong Zhuhai-Macau Bridge is an extraordinary engineering. It is the world's longest sea-crossing transportation system combining bridges and tunnels, which joins the three cities of Hong Kong Zhuhai and Macao, cutting the travelling time among them from 3 hours to 30 minutes. The reinforced concrete bridge with huge spans fully not only proves that China has the ability to complete the record-breaking mega-construction, but also will enhance the regional integration and boost the economic growth. It plays a crucial role in the overall plan to develop China’s Great Bay Area, which China intends to turn into one rivaling those of San Francisco, New York and Tokyo in terms of technological innovation and economic prosperity.", JSONEachRow=True))
 	#print (sntbr("[\u8bd1\u6587]The 55-kilometre Hong Kong Zhuhai-Macau Bridge is an extraordinary engineering. It is the world's longest sea-crossing transportation system combining bridges and tunnels, which joins the three cities of Hong Kong Zhuhai and Macao, cutting the travelling time among them from 3 hours to 30 minutes. The reinforced concrete bridge with huge spans fully not only proves that China has the ability to complete the record-breaking mega-construction, but also will enhance the regional integration and boost the economic growth. It plays a crucial role in the overall plan to develop China’s Great Bay Area, which China intends to turn into one rivaling those of San Francisco, New York and Tokyo in terms of technological innovation and economic prosperity."))
 
@@ -247,4 +301,24 @@ def topk_info(snts, docs,  topk, default_dims = {"internal_sim":0.2} ):
 	info.update(score.dims_score(dims))
 	info['pingyu'] = pingyu.get_pingyu(dims)
 	info['dims']   = dims  # new dsk format , /doc -> /info/dims 
-	return info 
\ No newline at end of file
+	return info 
+
+'''
+HSET "config:formula:default" "ast" "[9.9, 11.99, 15.3, 18.51, 25.32,				2,0.0882, 0.3241]"
+HSET "config:formula:default" "awl" "[3.5, 4.1, 4.56, 5.1, 6.0,					3,0.0882, 0.5]"
+HSET "config:formula:default" "b3" "[0, 0.03, 0.08, 0.12, 0.15 ,					1, 0.0956, 0.2096]"
+HSET "config:formula:default" "cl_sum" "[1, 6.68, 12, 16, 26,						2,0.0441, 0.1621]"
+HSET "config:formula:default" "grammar_correct_ri" "[0.6, 0.85, 0.92, 0.97,1.0,	2,0.0368, 0.1352]"
+HSET "config:formula:default" "internal_sim" "[0.0, 0.08, 0.2, 0.3, 0.4,			4, 0.0735, 0.7688]"
+HSET "config:formula:default" "kp_correct_ri" "[0.7, 0.9, 0.95, 0.97, 1,			1, 0.0368, 0.0807]"
+HSET "config:formula:default" "mwe_pv" "[0.01,8.03, 12, 20.21, 25,					4, 0.0221, 0.2312]"
+HSET "config:formula:default" "pred_diff_max3" "[3.84, 5.11, 6.51, 7.9, 10.09 ,	1, 0.0368, 0.0807]"
+HSET "config:formula:default" "prmods_ratio" "[0.06, 0.21, 0.3, 0.4, 0.5,			2, 0.0294, 0.108]"
+HSET "config:formula:default" "prmods_tc" "[1.1, 2.76, 4.75, 6.76, 10.0,			2, 0.0368, 0.1352]"
+HSET "config:formula:default" "simple_sent_ri" "[0.4, 0.65, 0.9, 0.95, 1,			2, 0.0368, 0.1352]"
+HSET "config:formula:default" "snt_correct_ratio" "[0.01, 0.2, 0.45, 0.75, 1,		1, 0.0368, 0.0807]"
+HSET "config:formula:default" "spell_correct_ratio" "[0.8, 0.9, 0.97, 0.99, 1,		1, 0.1471, 0.3226]"
+HSET "config:formula:default" "ttr1" "[3.43, 4.28, 5.2, 6, 6.8,					3, 0.0882, 0.5]"
+HSET "config:formula:default" "word_diff_avg" "[4.47, 4.73, 5.25,5.8, 6.6,			1, 0.0441, 0.0967]"
+HSET "config:formula:default" "word_gt7" "[0.11, 0.19, 0.3, 0.42, 0.49,			1, 0.0588, 0.1289]"
+'''
\ No newline at end of file
